@@ -12,8 +12,8 @@
 #include "dolphindebug.h"
 #include "dolphinmainwindow.h"
 #include "global.h"
-#include "config-kuserfeedback.h"
-#ifdef HAVE_KUSERFEEDBACK
+#include "config-dolphin.h"
+#if HAVE_KUSERFEEDBACK
 #include "userfeedback/dolphinfeedbackprovider.h"
 #endif
 
@@ -21,10 +21,13 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
-#include <Kdelibs4ConfigMigrator>
 #include <KConfigGui>
 #include <KIO/PreviewJob>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <Kdelibs4ConfigMigrator>
+#endif
+
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDBusConnection>
@@ -62,9 +65,10 @@ int main(int argc, char **argv)
     /**
      * enable high dpi support
      */
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-
+#endif
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("system-file-manager"), app.windowIcon()));
 
@@ -72,10 +76,12 @@ int main(int argc, char **argv)
 
     KCrash::initialize();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("dolphin"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("dolphinrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("dolphinpart.rc") << QStringLiteral("dolphinui.rc"));
     migrate.migrate();
+#endif
 
     KLocalizedString::setApplicationDomain("dolphin");
 
@@ -232,7 +238,7 @@ int main(int argc, char **argv)
         }
     }
 
-#ifdef HAVE_KUSERFEEDBACK
+#if HAVE_KUSERFEEDBACK
     auto feedbackProvider = DolphinFeedbackProvider::instance();
     Q_UNUSED(feedbackProvider)
 #endif
